# Code Functions for Formatting Strings
# This module provides functions to format strings in various ways.

def indian_format(x):
    x = str(x)
    if len(x) <= 3:
        return x
    s = x[:-4:-1] + ','
    g = ""
    for i, j in enumerate(x[-4::-1]):
        g += j
        if (i + 1) % 2 == 0 and i != len(x[-4::-1]) - 1:
            g += ','
    s= g[::-1] + s[::-1]
    return s



from setuptools import setup, find_packages

setup(
    
    name='harilib',
    version='0.1.0',
    packages=find_packages(),
    author='Your Name',
    author_email='your_email@example.com',
    description='Format numbers in Indian format like 12,34,567',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/yourusername/harilib',  # optional GitHub link
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
